%% plot_and_save.m
% UAV Software-in-the-Loop Simulation Verification Plots
%
% This script runs the SIL sim and plots the results.
%
%
% University of Minnesota 
% Aerospace Engineering and Mechanics 
% Copyright 2011 Regents of the University of Minnesota. 
% All rights reserved.
%
% SVN Info: $Id: plot_and_save.m 284 2011-03-03 15:07:19Z murch $

% Run simulation
sim('UAV_SIL', [0 45])

% Save the simulation data in the simData data structure.
simData.time= tout;
simData.elevator= elevator;
simData.aileron= aileron;
simData.rudder=rudder;
simData.flap= flap;
simData.V_s= V_s; 
simData.alt = alt; 
simData.phi=phi;
simData.theta = theta;
simData.psi=psi;
simData.theta_cmd=theta_cmd;
simData.phi_cmd= phi_cmd;
simData.p=p;
simData.q=q; % Pitch rate
simData.r=r ;
simData.alpha=alpha;
simData.beta=beta;

% save data
save simData simData;

%% SIMULATION RESULTS

% Plot Elevator response
figure(1), hold on, grid on
plot(simData.time, simData.elevator, 'b--', 'LineWidth',2);
title('SIL Elevator Deflection')
xlabel('time [s]'), ylabel('\delta_{elev} [deg]')

% Plot Aileron response
figure(2), hold on, grid on
plot(simData.time, simData.aileron, 'b--', 'LineWidth',2);
title('SIL Aileron Deflection')
xlabel('time [s]'), ylabel('\delta_{ail} [deg]')

% Plot Rudder response
figure(3), hold on, grid on
plot(simData.time, simData.rudder, 'b--', 'LineWidth',2);
title('SIL Rudder Deflection')
xlabel('time [s]'), ylabel('\delta_{rud} [deg]')

% Plot Flap response
figure(4), hold on, grid on
plot(simData.time, simData.flap, 'b--', 'LineWidth',2);
title('SIL Flap Deflection')
xlabel('time [s]'), ylabel('\delta_{flap} [deg]')

% Plot V_s response
figure(5), hold on, grid on
plot(simData.time,simData.V_s , 'b--', 'LineWidth', 2);
title('SIL V_s Response')
xlabel('time [s]'), ylabel('V_s [m/s]')

% Plot Angle of Attack response
figure(6), hold on, grid on
plot(simData.time, simData.alpha, 'b--', 'LineWidth', 2);
title('SIL Angle of Attack Response')
xlabel('time [s]'), ylabel('\alpha [deg]')

% Plot Sideslip response
figure(7), hold on, grid on
plot(simData.time,simData.beta, 'b--', 'LineWidth', 2);
title('SIL Sideslip Response')  
xlabel('time [s]'), ylabel('\beta [deg]')

% Plot Bank Angle response
% figure, hold on, grid on
% plot(simData.time, simData.phi, 'b--', 'LineWidth', 2);
% title('SIL Bank Angle Response')  
% xlabel('time [s]'), ylabel('\phi [deg]')

% Plot Bank Angle Commanded/Actual
figure(8), hold on, grid on
plot(simData.time, simData.phi_cmd, 'k', 'LineWidth', 2)
plot(simData.time, simData.phi, 'b--','LineWidth',2)
title('SIL Bank Angle Comparison')
xlabel('time [s]'), ylabel('\phi [deg]')
legend('Commanded \phi','Actual \phi')

% Plot Pitch Angle response
% figure, hold on, grid on
% plot(simData.theta.time, simData.theta, 'b--', 'LineWidth', 2);
% title('SIL Pitch Angle Response')  
% xlabel('time [s]'), ylabel('\theta [deg]')

% Plot Pitch Angle Commanded/Actual
figure(9), hold on, grid on
plot(simData.time, simData.theta_cmd, 'k', 'LineWidth', 2)
plot(simData.time, simData.theta, 'b--','LineWidth',2)
title('SIL Pitch Angle Comparison')
xlabel('time [s]'), ylabel('\theta [deg]')
legend('Commanded \theta','Actual \theta')

% Plot Yaw Angle response
figure(10), hold on, grid on
plot(simData.time, simData.psi, 'b--', 'LineWidth', 2);
title('SIL Heading Angle Response')
xlabel('time [s]'), ylabel('\psi [deg]')

% Plot altitude response
figure(11), hold on, grid on
plot(simData.time, simData.alt, 'b--', 'LineWidth', 2);
title('SIL altitude (above Ground Level) Response')
xlabel('time [s]'), ylabel('alt [m]')

% Plot roll rate response
figure(12), hold on, grid on
plot(simData.time, simData.p, 'b--', 'LineWidth', 2);
title('SIL Roll Rate Response')
xlabel('time [s]'), ylabel('p [deg/s]')

% Plot pitch rate response
figure(13), hold on, grid on
plot(simData.time, simData.q, 'b--', 'LineWidth', 2);
title('SIL Pitch Rate Response')
xlabel('time [s]'), ylabel('q [deg/s]')

% Plot yaw rate response
figure(14), hold on, grid on
plot(simData.time, simData.r, 'b--', 'LineWidth', 2);
title('SIL Yaw Rate Response')
xlabel('time [s]'), ylabel('r [deg/s]')
