/*
 * FILE: L_sensordaq.c
 * DESCRIPTION:
 *
 *
 *  Created on: Feb 27, 2010
 *      Author: Rohit Pandita
 *
 * University of Minnesota 
 * Aerospace Engineering and Mechanics 
 *  2011 Regents of the University of Minnesota. All rights reserved.
 *
 * $Id: L_sensordaq.c 253 2011-01-20 22:01:35Z murch $ */

#include <cyg/infra/diag.h>             // HAL polled output

#include "globaldefs.h"
#include "utils/serial_mpc5200.c"
#include "sensors/sensors.c"

#ifdef SIRF
#include "sensors/GPS/gps_sirf.c"
#endif

#ifdef CRESCENT
#include "sensors/GPS/gps_crescent.c"
#endif


void *sensordaq(void *thread_id)
{
	//	const int verbose = 0;
	int rc, gpstimer=0;
	static double tic;
	double toc;
	int gpspackets;

	/* Initialize sensors */
	sPort2 = init_gps( SERIAL_PORT2, B57600 );		/* GPS */
	init_spi();		/* IMU */
	init_i2c();		/* Ps,Pd */

	// initialize as nolock
	gpspacket.err_type = gps_nolock;

	while ( ofpMode != terminate )
	{
		pthread_mutex_lock (&mutex_imu);
		rc = pthread_cond_wait (&trigger_sensordaq, &mutex_imu);

		if (rc == 0) {
			pthread_mutex_unlock (&mutex_imu);
			// compute thread jitter
			toc = get_Time();
			threadstat[0].jitter_nsec = ( (toc-tic) - 1/(double)DAQ_Hz ) * 1E09;
			tic = toc;


			read_spi( &imupacket );		// cyg_delay=5 ticks
			read_pspd( &imupacket );
			pthread_cond_signal( &trigger_ahrs );

			// acquire gps data at 1hz
			if ( ++gpstimer >= DAQ_Hz ){
				pthread_mutex_lock( &mutex_gps );
//				fprintf(stderr,"\n *jitter*:%dns",threadstat[0].jitter_nsec);

				for( gpspackets=0; gpspackets<6; gpspackets++ )
					read_gps( &gpspacket, sPort2 );

				//pthread_cond_signal (&trigger_navigation);
				pthread_mutex_unlock( &mutex_gps );
				gpstimer = 0;	// reset counter
			}

//			pthread_mutex_unlock (&mutex_imu);
		}	/* end while */
	}

	// free i2c malloc'ed datastructs
	delete_HoneywellAltimeter( myAltimeter );
	delete_HoneywellPitot( myPitot );
	
	
	//close the serial port
	close(sPort2);
	//exit the thread
	pthread_exit(NULL);
}
